# pyinkscape

[![ReadTheDocs Badge](https://readthedocs.org/projects/pyinkscape/badge/?version=latest&style=plastic)](https://pyinkscape.readthedocs.io/)

A library to manipulate Inkscape SVG content using Python 3

## A quick look

To run piechart demo, please try:
```bash
python3 -m pip install --user pyinkscape
python3 demo_piechart.py
```

![Pie chart Inkscape/SVG Demo](./web/pie.svg)

## Useful Links

- pyInkscape documentation: https://pyinkscape.readthedocs.io/
- pyInkscape on PyPI: https://pypi.org/project/pyinkscape/
- Soure code: https://github.com/letuananh/pyinkscape/
